package cd.casic.ci.common.pipeline.pojo.cascade;

import cd.casic.ci.common.pipeline.enums.BuildFormPropertyType;
import cd.casic.ci.common.pipeline.enums.ScmType;
import cd.casic.ci.common.pipeline.pojo.BuildFormValue;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @Author：mianbin
 * @Package：cd.casic.ci.common.pipeline.pojo.cascade
 * @Project：ops-pro
 * @name：RepoRefCascadeParam
 * @Date：2025/03/26 10:06
 * @Filename：RepoRefCascadeParam
 * @description：Todo
 */

public class RepoRefCascadeParam extends CascadeParam {
    public static final String SELECTOR_KEY_REPO_NAME = "repo-name";
    public static final String SELECTOR_KEY_BRANCH = "branch";
    private static final List<ScmType> SUPPORT_REPO_TYPE = Arrays.asList(
            ScmType.CODE_GIT,
            ScmType.GITHUB,
            ScmType.CODE_SVN,
            ScmType.CODE_TGIT,
            ScmType.CODE_GITLAB
    );

    public RepoRefCascadeParam() {
        super(BuildFormPropertyType.REPO_REF, Arrays.asList(SELECTOR_KEY_REPO_NAME, SELECTOR_KEY_BRANCH));
    }

    @Override
    public Map<String, CascadeParamPropsHandler> chainHandler() {
        return Map.of(
                SELECTOR_KEY_REPO_NAME, repoNameHandler(),
                SELECTOR_KEY_BRANCH, branchHandler()
        );
    }

    private CascadeParamPropsHandler repoNameHandler() {
        return (key, defaultValue, projectId) -> {
            String repositoryTypes = SUPPORT_REPO_TYPE.stream().map(Enum::name).collect(Collectors.joining(","));
            return new BuildCascadeProps(
                    key,
                    Collections.singletonList(new BuildFormValue(defaultValue, defaultValue)),
                    "process/api/user/buildParam/repository/" + projectId + "/aliasName?aliasName={words}&permission=LIST&repositoryType=" + repositoryTypes,
                    "{words}",
                    null
            );
        };
    }

    private CascadeParamPropsHandler branchHandler() {
        return (key, defaultValue, projectId) -> new BuildCascadeProps(
                key,
                Collections.singletonList(new BuildFormValue(defaultValue, defaultValue)),
                "/process/api/user/buildParam/" + projectId + "/repository/refs?search={branch}&repositoryType=NAME&repositoryId={parentValue}",
                "{branch}",
                null
        );
    }

    public static Map<String, String> variableKeyMap(String key) {
        return Map.of(
                SELECTOR_KEY_REPO_NAME, key + "." + SELECTOR_KEY_REPO_NAME,
                SELECTOR_KEY_BRANCH, key + "." + SELECTOR_KEY_BRANCH
        );
    }

    public static Map<String, String> defaultValue() {
        return Map.of(
                SELECTOR_KEY_REPO_NAME, "",
                SELECTOR_KEY_BRANCH, ""
        );
    }
}