package cd.casic.pipeline.store.api.common;


import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.pipeline.store.pojo.common.classify.Classify;
import cd.casic.pipeline.store.pojo.common.classify.ClassifyRequest;
import cd.casic.pipeline.store.pojo.common.enums.StoreTypeEnum;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;

import java.util.List;


@Tag(name = "OP_STORE_CLASSIFY", description = "OP-STORE-分类")
@RestController
@RequestMapping("/op/store/classify")
public interface OpClassifyResource {

    @Operation(summary = "添加分类")
    @PostMapping("/types/{classifyType}")
    CommonResult<Boolean> add(
            @Parameter(description = "类别", required = true)
            @PathVariable("classifyType")
            StoreTypeEnum classifyType,
            @Parameter(description = "分类信息请求报文体", required = true)
            ClassifyRequest classifyRequest
    );

    @Operation(summary = "更新分类信息")
    @PutMapping("/types/{classifyType}/ids/{id}")
    CommonResult<Boolean> update(
            @Parameter(description = "类别", required = true)
            @PathVariable("classifyType")
            StoreTypeEnum classifyType,
            @Parameter(description = "分类ID", required = true)
            @PathVariable("id")
            String id,
            @Parameter(description = "分类信息请求报文体", required = true)
            ClassifyRequest classifyRequest
    );

    @Operation(summary = "获取所有分类信息")
    @GetMapping("/types/{classifyType}")
    CommonResult<List<Classify>> listAllClassifys(
            @Parameter(description = "类别", required = true)
            @PathVariable("classifyType")
            StoreTypeEnum classifyType
    );

    @Operation(summary = "根据ID获取分类信息")
    @GetMapping("/{id}")
    CommonResult<Classify> getClassifyById(
            @Parameter(description = "分类ID", required = true)
            @RequestParam("id")
            String id
    );

    @Operation(summary = "根据ID删除分类信息")
    @DeleteMapping("/{id}")
    CommonResult<Boolean> deleteClassifyById(
            @Parameter(description = "分类ID", required = true)
            @PathVariable("id")
            String id
    );
}